# coding: utf-8

"""
    Mayanode API

    Mayanode REST API.  # noqa: E501

    OpenAPI spec version: 1.107.3
    Contact: devs@mayachain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_mayanode
from xchainpy2_mayanode.models.keygen_metric1 import KeygenMetric1  # noqa: E501
from xchainpy2_mayanode.rest import ApiException


class TestKeygenMetric1(unittest.TestCase):
    """KeygenMetric1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testKeygenMetric1(self):
        """Test KeygenMetric1"""
        # FIXME: construct object with mandatory attributes with example values
        # model = xchainpy2_mayanode.models.keygen_metric1.KeygenMetric1()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
